@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::dilbert;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -41,6 +41,12 @@ Sbastien Aperghis-Tramoni.
 
 =item *
 
+2014-04-07 - v1.005
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.039.
+
+=item *
+
 2013-06-17 - v1.004
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.033.
@@ -242,3 +248,4 @@ tom_jackson trixie victor vlad wolfgang
 jb_hopper
 stanky_bathurd
 wulf
+mullah_john_smith
