@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::icao;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2015-08-10 - v1.003
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.047.
+
+=item *
+
 2015-06-08 - v1.002
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.046.
@@ -580,9 +586,9 @@ UHWW UIAA UIII UIIO UIKB UIKK UINN UIUH UIUU UKBB UKBD UKCC UKCM UKCW
 UKDD UKDE UKDR UKFB UKFF UKFK UKFW UKFY UKHE UKHH UKHK UKHP UKHS UKII
 UKKE UKKG UKKH UKKJ UKKK UKKM UKKS UKKT UKKV UKLC UKLH UKLI UKLL UKLN
 UKLR UKLT UKLU UKOH UKOI UKOM UKON UKOO UKOX UKRR UKWW ULAA ULAK ULLI
-ULMM ULOL ULWT ULWW UMBB UMGG UMII UMMG UMMM UMMS UNBB UNCE UNEE UNII
+ULMM ULOL ULWT ULWW UMBB UMGG UMII UMMG UMMM UMMS UNBB UNCE UNEE UNII UNKK
 UNKL UNNT UNTT URKK URMM URRR URSS URWA URWI URWW USHH USPP USRR USSE
-USSS UTAA UTDD UTDL UTED UTSM UTSS UTST UTTT UUBP UUDD UUEE UUEM UUOO
+USSS UTAA UTDD UTDL UTED UTSM UTSS UTST UTTT UUBP UUDD UUEE UUEM UUOO UUWE
 UUWW UUYT UUYY UWGG UWKD UWLW UWPP UWUU UWWW VAAH VAAK VAAU VABB VABI
 VABJ VABM VABP VABV VADN VAGO VAID VAJB VAKD VAKE VAKP VANP VARK VASL
 VASU VCBI VCCA VCCB VCCC VCCG VCCT VCCW VDBG VDKC VDPP VDSR VDST VEAT
