@@ -21,10 +21,29 @@ Read it at L<http://www.userfriendly.org/>.
 
 Abigail
 
-Introduced in Acme-MetaSyntactic version 0.74, published on May 15, 2006.
+=head1 CHANGES
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=over 4
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2006-05-15
+
+Introduced in Acme-MetaSyntactic version 0.74.
+
+=item *
+
+2005-10-27
+
+Submitted by Abigail.
+
+=back
 
 =head1 SEE ALSO
 
